@@ -90,7 +90,7 @@ SUB = Literal("-").set_parser_name("sub")
 BINARY_NOT = Literal("~").set_parser_name("binary_not")
 BINARY_AND = Literal("&").set_parser_name("binary_and")
 BINARY_OR = Literal("|").set_parser_name("binary_or")
-GTE = Literal(">=").set_parser_name("gte")
+GTE = (Literal(">=") | Literal("=>")).set_parser_name("gte")
 LTE = Literal("<=").set_parser_name("lte")
 LT = Literal("<").set_parser_name("lt")
 GT = Literal(">").set_parser_name("gt")
